@@ -5,9 +5,7 @@ _T = TypeVar("_T")
 
 
 def exist(value: _T | None) -> TypeIs[_T]:
-    if value is None:
-        return False
-    return True
+    return value is not None
 
 
 PartialList: TypeAlias = list[_T] | list[None] | list[_T | None]
